AFeedParsingService class abstract

Interface for a service that retrieves a list of FeedEntryModels You can build your own by implementing it

Constructors

AFeedParsingService(String trigger, String id)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger String
The trigger is used to identify if a post should be included or not in the list
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseFeed() Future<List<FeedEntryModel>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited